<?php

namespace Bolt\Extension\Ginger\Squarepay\Twig;

use Silex\Application;

/**
 * Twig runtime class that will only be invoked when one of its functions or
 * filters are used.
 *
 * @author Richard Knight <rich@apewave.com>
 */
class SquareTwigRuntime
{
    private $apiClient;

	public function __construct($apiClient, $twig, $config, $basket)
	{
		$this->apiClient = $apiClient;
		$this->twig = $twig;
		$this->config = $config;
		$this->basket = $basket;
	}

	public function getCatalog()
	{
		try {
			$catalogApi = new \SquareConnect\Api\CatalogApi($this->apiClient);
			$response = $catalogApi->listCatalog();
		} catch (Exception $e) {
			error_log($e->getMessage());
			return 'ERROR: '.$e->getMessage();
		}
		$products = [];
		foreach($response['objects'] as $p) {
			if ($p['type'] === 'ITEM') {
				array_push($products, $p);
			}
		}
		return $products;
	}
	
	public function getCatalogItem($catId)
	{
		try {
			$catalogApi = new \SquareConnect\Api\CatalogApi($this->apiClient);
			$response = $catalogApi->retrieveCatalogObject($catId);
		} catch (Exception $e) {
			error_log($e->getMessage());
			return 'ERROR: '.$e->getMessage();
		}
		return $response['object'];
	}

	public function getBasket()
	{
		return [
			'basket' => $this->basket,
			'total'  => array_sum(array_column($this->basket, 'total'))
		];
	}
	
	public function displayCCForm() {
		$context = $this->config;
		return $this->twig->render('@Squarefront/cardentryform.twig', $context);
	}

}
